@@ -5,9 +5,9 @@ from votebase.core.voting.models import VotedQuestion
 
 class Command(BaseCommand):
     def handle(self, *args, **options):
-        segment_slug = args[0]
+        survey_slug = args[0]
 
-        voted_questions = VotedQuestion.objects.filter(question__survey__round__slug=segment_slug, quiz_result=None)
+        voted_questions = VotedQuestion.objects.filter(question__survey__slug=survey_slug, quiz_result=None)
         progress = ProgressBar(voted_questions.count()).start()
 
         counter = 0
@@ -19,4 +19,4 @@ class Command(BaseCommand):
             counter += 1
             progress.update(counter)
 
-        progress.finish()
\ No newline at end of file
+        progress.finish()
